import os
import sys
import tkinter as tk

from .configurable_tool_demo import DemoTool

def main():
    root = tk.Tk()
    root.title("ConfigurableTool Demo")
    root.geometry("800x600")
    
    app = DemoTool(root)
    app.pack(fill=tk.BOTH, expand=True)
    
    root.mainloop()

if __name__ == "__main__":
    # 添加项目根目录到 Python 路径
    project_root = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))))
    sys.path.insert(0, project_root)
    main() 